ComposedFontSystem

Struct ComposedFontSystem 

pub struct ComposedFontSystem<L, S> { /* private fields */ }
Font system assembled from independent loading and shaping services.

Implementations

Source

impl<L, S> ComposedFontSystem<L, S>

pub fn new(loader: L, shaper: S) -> Self

Create a font system from a loader and shaper.

pub fn loader(&self) -> &L

Borrow the font loader.

pub fn shaper(&self) -> &S

Borrow the text shaper.

pub fn into_parts(self) -> (L, S)

Split this font system into its loader and shaper.