pub struct InMemoryFontLoader { /* private fields */ }Expand description
Loads fonts from an in process map keyed by file name.
Implementations
Sourceimpl InMemoryFontLoader
impl InMemoryFontLoader
Sourcepub fn with_font(
self,
file: impl Into<String>,
bytes: impl Into<Arc<[u8]>>,
) -> Self
pub fn with_font( self, file: impl Into<String>, bytes: impl Into<Arc<[u8]>>, ) -> Self
Adds a font by file name and returns the loader.
Sourcepub fn insert(
&mut self,
file: impl Into<String>,
bytes: impl Into<Arc<[u8]>>,
) -> FontKey
pub fn insert( &mut self, file: impl Into<String>, bytes: impl Into<Arc<[u8]>>, ) -> FontKey
Adds or replaces a font by file name and returns its key, keys are never reused.
Sourcepub fn insert_font_data(&mut self, file: impl Into<String>, font: FontData)
pub fn insert_font_data(&mut self, file: impl Into<String>, font: FontData)
Adds or replaces a font the host built, keeping the host’s key.