SharedFace

Trait SharedFace 

pub trait SharedFace: Send + Sync {
    // Required method
    fn rustybuzz_face(&self) -> &Face<'_>;

    // Provided method
    fn ttf_face(&self) -> &Face<'_> { ... }
}
A face the host parsed and owns, the library borrows it and never parses or copies it.

Required Methods

fn rustybuzz_face(&self) -> &Face<'_>

Returns the rustybuzz face the host parsed.

Provided Methods

fn ttf_face(&self) -> &Face<'_>

Returns the ttf view of the face, by default the one inside the rustybuzz face.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors