pub trait SharedFace: Send + Sync {
// Required method
fn rustybuzz_face(&self) -> &Face<'_>;
// Provided method
fn ttf_face(&self) -> &Face<'_> { ... }
}Expand description
A face the host parsed and owns, the library borrows it and never parses or copies it.
Required Methods
Sourcefn rustybuzz_face(&self) -> &Face<'_>
fn rustybuzz_face(&self) -> &Face<'_>
Returns the rustybuzz face the host parsed.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".